@@ -17,14 +17,17 @@ module.exports = { // eslint-disable-line no-undef
             [process.env.SRC_PATH + "/testing/eslint_import_resolver"]: {}
         }
     },
-    "parser": "babel-eslint",
     "parserOptions": {
         "sourceType": "module",
         "allowImportExportEverywhere": true,
         "ecmaFeatures": {
             "globalReturn": false,
         },
-        "ecmaVersion": 2020
+        "ecmaVersion": 2022,
+        "requireConfigFile": false,
+        "babelOptions": {
+            "presets": ["@babel/preset-env"]
+        }
     },
     "rules": {
         "accessor-pairs": "error",
@@ -247,7 +250,7 @@ module.exports = { // eslint-disable-line no-undef
         "prefer-spread": "error",
         "prefer-template": "off",
         "quote-props": "off",
-        "quotes": "off",
+        "quotes": "error",
         "radix": [
             "error",
             "as-needed"
@@ -295,6 +298,7 @@ module.exports = { // eslint-disable-line no-undef
     },
     "globals": {
         "gettext": "readonly",
+        "staticUrl": "readonly",
         "interpolate": "readonly",
         "settings_STATIC_URL": "readonly",
         "settings_REGISTRATION_OPEN": "readonly",
