@@ -1,5 +1,6 @@
 import os
-from django.conf import settings
+from django.conf import settings as django_settings
+
 """
 Application that contains main app settings
 (Hosts, middleware, templates, installed apps)
@@ -7,16 +8,10 @@ Urls to route between applications,
 statics that are shared among different django applications
 Also contains helper for starting tornado server and management commands
 """
-default_app_config = 'base.apps.BaseConfig'
 
 
 def read_version():
-    with open(
-        os.path.join(
-            settings.SRC_PATH,
-            "version.txt"
-        )
-    ) as f:
+    with open(os.path.join(django_settings.SRC_PATH, "version.txt")) as f:
         return f.read().splitlines()[0]
 
 
