@@ -14,7 +14,7 @@ def ajax_required(f):
     """
 
     def wrap(request, *args, **kwargs):
-        if not request.is_ajax():
+        if not request.headers.get("x-requested-with") == "XMLHttpRequest":
             return HttpResponseBadRequest()
         return f(request, *args, **kwargs)
 
