@@ -1,6 +1,6 @@
 import os
 from django.core.management.commands.compilemessages import (
-    Command as CompilemessagesCommand
+    Command as CompilemessagesCommand,
 )
 
 from base.management import BaseCommand
@@ -8,9 +8,9 @@ from base.management import BaseCommand
 
 class Command(CompilemessagesCommand, BaseCommand):
     def handle(self, *args, **options):
-        if os.environ.get('NO_COMPILEMESSAGES') == 'true':
+        if os.environ.get("NO_COMPILEMESSAGES") == "true":
             self.stdout.write(
-                'Using packaged version. Skipping compile messages.'
+                "Using packaged version. Skipping compile messages."
             )
         else:
             return super().handle(*args, **options)
