@@ -1,5 +1,6 @@
-import {CSL} from 'citeproc-plus'
-import * as OfflinePluginRuntime from '@lcdp/offline-plugin/runtime'
+import {CSL} from "citeproc-plus"
+//import * as OfflinePluginRuntime from "@lcdp/offline-plugin/runtime"
+
 import {ContactInvite} from "../contacts/invite"
 import {ImageOverview} from "../images/overview"
 import {ContactsOverview} from "../contacts"
@@ -16,19 +17,21 @@ import {OfflinePage} from "../offline"
 import {SetupPage} from "../setup"
 import {FlatPage} from "../flatpage"
 import * as plugins from "../../plugins/app"
-import {IndexedDB} from '../indexed_db'
+import {IndexedDB} from "../indexed_db"
 
 export class App {
     constructor() {
         this.config = {}
-        this.name = 'Fidus Writer'
+        this.name = "Fidus Writer"
         this.config.app = this
         this.routes = {
             "": {
+                app: "document",
                 requireLogin: true,
                 open: () => import(/* webpackPrefetch: true */"../documents/overview").then(({DocumentOverview}) => new DocumentOverview(this.config))
             },
             "account": {
+                app: "user",
                 requireLogin: false,
                 open: pathnameParts => {
                     let returnValue
@@ -56,18 +59,20 @@ export class App {
                 }
             },
             "bibliography": {
+                app: "bibliography",
                 requireLogin: true,
                 open: () => import("../bibliography/overview").then(({BibliographyOverview}) => new BibliographyOverview(this.config))
             },
             "document": {
+                app: "document",
                 requireLogin: true,
                 open: pathnameParts => {
                     let id = pathnameParts.pop()
                     if (!id.length) {
                         id = pathnameParts.pop()
                     }
-                    const path = ('/' + pathnameParts.slice(2).join('/')).replace(/\/?$/, '/')
-                    return import(/* webpackPrefetch: true *//* webpackChunkName: "editor" */'../editor').then(({Editor}) => new Editor(this.config, path, id))
+                    const path = ("/" + pathnameParts.slice(2).join("/")).replace(/\/?$/, "/")
+                    return import(/* webpackPrefetch: true *//* webpackChunkName: "editor" */"../editor").then(({Editor}) => new Editor(this.config, path, id))
                 },
                 dbTables: {
                     "data": {
@@ -76,19 +81,22 @@ export class App {
                 }
             },
             "documents": {
+                app: "document",
                 requireLogin: true,
                 open: pathnameParts => {
-                    const path = decodeURI(('/' + pathnameParts.slice(2).join('/')).replace(/\/?$/, '/'))
+                    const path = (("/" + pathnameParts.slice(2).join("/")).replace(/\/?$/, "/"))
                     return import(/* webpackPrefetch: true */"../documents/overview").then(({DocumentOverview}) => new DocumentOverview(this.config, path))
                 }
             },
             "pages": {
+                app: "base",
                 open: pathnameParts => {
                     const url = `/${pathnameParts[2]}/`
                     return new FlatPage(this.config, url)
                 }
             },
             "user": {
+                app: "user",
                 requireLogin: true,
                 open: pathnameParts => {
                     let returnValue
@@ -111,12 +119,14 @@ export class App {
                 }
             },
             "invite": {
+                app: "user",
                 open: pathnameParts => {
                     const id = pathnameParts[2]
                     return new ContactInvite(this.config, id)
                 }
             },
             "usermedia": {
+                app: "usermedia",
                 requireLogin: true,
                 open: () => new ImageOverview(this.config)
             }
@@ -133,26 +143,42 @@ export class App {
     }
 
     alertCached() {
-        addAlert('info', gettext('You are viewing a cached version of this page.'))
+        addAlert("info", gettext("You are viewing a cached version of this page."))
     }
 
     installServiceWorker() {
         /* This function is used for testing SW with Django tests */
-        OfflinePluginRuntime.install({
-            onUpdateReady: () => OfflinePluginRuntime.applyUpdate(),
-            onUpdated: () => window.location.reload()
-        })
+        if ("serviceWorker" in navigator) {
+            navigator.serviceWorker.register("/sw.js").then(registration => {
+                console.log("SW registered: ", registration)
+            }).catch(registrationError => {
+                console.log("SW registration failed: ", registrationError)
+            })
+        }
+
+        // OfflinePluginRuntime.install({
+        //     onUpdateReady: () => OfflinePluginRuntime.applyUpdate(),
+        //     onUpdated: () => window.location.reload()
+        // })
     }
 
     init() {
-        if (!settings_DEBUG && settings_USE_SERVICE_WORKER) {
-            OfflinePluginRuntime.install({
-                onUpdateReady: () => OfflinePluginRuntime.applyUpdate(),
-                onUpdated: () => this.handleSWUpdate()
-            })
+        if (!settings_DEBUG && settings_USE_SERVICE_WORKER && "serviceWorker" in navigator) {
+            navigator.serviceWorker.register("/sw.js").then(
+                registration => {
+                    console.log("SW registered: ", registration)
+                }).catch(
+                registrationError => {
+                    console.log("SW registration failed: ", registrationError)
+                }
+            )
         }
+        // OfflinePluginRuntime.install({
+        //     onUpdateReady: () => OfflinePluginRuntime.applyUpdate(),
+        //     onUpdated: () => this.handleSWUpdate()
+        // })
         ensureCSS([
-            'fontawesome/css/all.css'
+            staticUrl("css/fontawesome/css/all.css")
         ])
         if (this.isOffline()) {
             this.page = this.openOfflinePage()
@@ -225,25 +251,25 @@ export class App {
 
     bind() {
         window.onpopstate = () => this.selectPage()
-        document.addEventListener('click', event => {
+        document.addEventListener("click", event => {
             const el = {}
             switch (true) {
-            case findTarget(event, 'a', el):
+            case findTarget(event, "a", el):
                 if (
                     el.target.hostname === window.location.hostname &&
-                        el.target.getAttribute('href')[0] === '/' &&
-                        el.target.getAttribute('href').slice(0, 7) !== '/media/' &&
-                        el.target.getAttribute('href').slice(0, 5) !== '/api/'
+                        el.target.getAttribute("href")[0] === "/" &&
+                        el.target.getAttribute("href").slice(0, 7) !== "/media/" &&
+                        el.target.getAttribute("href").slice(0, 5) !== "/api/"
                 ) {
                     event.preventDefault()
                     event.stopImmediatePropagation()
-                    this.goTo(el.target.href)
+                    this.goTo(decodeURI(el.target.href))
                 }
                 break
             }
         })
         let resizeDone
-        window.addEventListener('resize', () => {
+        window.addEventListener("resize", () => {
             clearTimeout(resizeDone)
             resizeDone = setTimeout(() => {
                 if (this.page && this.page.onResize) {
@@ -251,13 +277,13 @@ export class App {
                 }
             }, 250)
         })
-        window.addEventListener('beforeunload', event => {
+        window.addEventListener("beforeunload", event => {
             if (this.page && this.page.onBeforeUnload) {
                 if (this.page.onBeforeUnload()) {
                     event.preventDefault()
                     // To stop the event for chrome and safari
-                    event.returnValue = ''
-                    return ''
+                    event.returnValue = ""
+                    return ""
                 }
             }
         })
@@ -265,20 +291,20 @@ export class App {
 
     showNews() {
         if (
-            window.location.pathname !== '/user/contacts/' &&
+            window.location.pathname !== "/user/contacts/" &&
             this.config.user.waiting_invites
         ) {
             showSystemMessage(
-                gettext('Other users have requested to connect with you. Go to the contacts page to accept their invites.'),
+                gettext("Other users have requested to connect with you. Go to the contacts page to accept their invites."),
                 [
                     {
-                        text: gettext('Go to contacts'),
-                        classes: 'fw-dark',
+                        text: gettext("Go to contacts"),
+                        classes: "fw-dark",
                         click: _event => {
-                            return this.goTo('/user/contacts/')
+                            return this.goTo("/user/contacts/")
                         }
                     },
-                    {type: 'close'}
+                    {type: "close"}
                 ]
             )
         }
@@ -286,11 +312,11 @@ export class App {
 
     connectWs() {
         this.ws = new WebSocketConnector({
-            url: '/ws/base/',
+            url: "/ws/base/",
             appLoaded: () => true,
             receiveData: data => {
                 switch (data.type) {
-                case 'message':
+                case "message":
                     showSystemMessage(data.message)
                     break
                 default:
@@ -311,7 +337,7 @@ export class App {
         this.plugins = {}
 
         Object.keys(plugins).forEach(plugin => {
-            if (typeof plugins[plugin] === 'function') {
+            if (typeof plugins[plugin] === "function") {
                 this.plugins[plugin] = new plugins[plugin](this)
                 this.plugins[plugin].init()
             }
@@ -322,7 +348,7 @@ export class App {
         if (this.page && this.page.close) {
             this.page.close()
         }
-        const pathnameParts = window.location.pathname.split('/')
+        const pathnameParts = decodeURI(window.location.pathname).split("/")
         const route = this.routes[pathnameParts[1]]
         if (route) {
             if (
@@ -360,13 +386,13 @@ export class App {
     }
 
     getUserInfo() {
-        return postJson('/api/base/configuration/').then(
+        return postJson("/api/base/configuration/").then(
             ({json}) => Object.entries(json).forEach(([key, value]) => this.config[key] = value)
         )
     }
 
     goTo(url) {
-        window.history.pushState({}, "", url)
+        window.history.pushState({}, "", encodeURI(url))
         return this.selectPage()
     }
 
