@@ -1,5 +1,5 @@
 export class VerbatimFieldForm {
-    constructor(dom, initialValue = '', placeHolder = '') {
+    constructor(dom, initialValue = "", placeHolder = "") {
         this.dom = dom
         this.initialValue = initialValue
         this.placeHolder = placeHolder
@@ -10,7 +10,7 @@ export class VerbatimFieldForm {
     }
 
     get value() {
-        const formValue = this.dom.querySelector('input.verbatim').value
+        const formValue = this.dom.querySelector("input.verbatim").value
         // If the form has not been filled out, don't consider this form
         return formValue.length > 0 ? formValue : false
     }
