@@ -1,7 +1,7 @@
 from django.contrib import admin
 from django.shortcuts import render
 from django.urls import path
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 from . import models
 
 
