@@ -1,4 +1,4 @@
-import {escapeText} from "../../common"
+import {avatarTemplate, escapeText} from "../../common"
 
 /** The access rights dialogue template */
 export const accessRightOverviewTemplate = ({contacts, collaborators}) =>
@@ -33,19 +33,19 @@ export const contactsTemplate = ({contacts}) =>
     contacts.map(contact =>
         `<tr>
             <td width="337" data-id="${contact.id}" data-type="${contact.type}" class="fw-checkable fw-checkable-td">
-                <span>${contact.avatar.html}</span>
+                <span>${avatarTemplate({user: contact})}</span>
                 <span class="fw-inline">
                 ${
-    contact.type === 'userinvite' ?
-        `${gettext('Invite')}:&nbsp;` :
-        ''
+    contact.type === "userinvite" ?
+        `${gettext("Invite")}:&nbsp;` :
+        ""
 }
                     ${escapeText(contact.name)}
 
                 </span>
             </td>
         </tr>`
-    ).join('')
+    ).join("")
 
 /** The template for the right hand side list of users (the collaborators of the current document) of the access rights dialogue. */
 export const collaboratorsTemplate = ({collaborators}) =>
@@ -54,11 +54,11 @@ export const collaboratorsTemplate = ({collaborators}) =>
     data-type="${collaborator.holder.type}" data-id="${collaborator.holder.id}"
     class="collaborator-tr" data-rights="${collaborator.rights}">
         <td width="215">
-            <span>${collaborator.holder.avatar.html}</span>
+            <span>${avatarTemplate({user: collaborator.holder})}</span>
             <span class="fw-inline">${
-    collaborator.holder.type === 'userinvite' ?
-        `${gettext('Invite')}: ` :
-        ''
+    collaborator.holder.type === "userinvite" ?
+        `${gettext("Invite")}: ` :
+        ""
 }${escapeText(collaborator.holder.name)}</span>
         </td>
         <td width="50" align="center">
@@ -73,4 +73,4 @@ export const collaboratorsTemplate = ({collaborators}) =>
             </span>
         </td>
     </tr>`
-    ).join('')
+    ).join("")
