@@ -6,13 +6,13 @@ export const notifyMentionedUser = (docId, userId, comment) => {
 
     const {html, text} = serializeCommentNode(comment)
     return post(
-        '/api/document/comment_notify/',
+        "/api/document/comment_notify/",
         {
             doc_id: docId,
             collaborator_id: userId,
             comment_html: html,
             comment_text: text,
-            type: 'mention'
+            type: "mention"
         }
     )
 }
