@@ -9,10 +9,10 @@ export class LinkDialog {
     constructor(editor) {
         this.editor = editor
         this.target = false // cross reference or internal link
-        this.linkType = 'external'
-        this.defaultLink = 'https://'
-        this.title = ''
-        this.submitButtonText = gettext('Insert')
+        this.linkType = "external"
+        this.defaultLink = "https://"
+        this.title = ""
+        this.submitButtonText = gettext("Insert")
         this.dialog = false
         this.internalTargets = []
     }
@@ -25,12 +25,12 @@ export class LinkDialog {
         this.internalTargets = getInternalTargets(
             this.editor.view.state,
             this.editor.view.state.doc.firstChild.attrs.language,
-            'main'
+            "main"
         ).concat(
             getInternalTargets(
                 this.editor.mod.footnotes.fnEditor.view.state,
                 this.editor.view.state.doc.firstChild.attrs.language,
-                'foot'
+                "foot"
             )
         )
         this.createDialog()
@@ -42,30 +42,30 @@ export class LinkDialog {
         const state = this.editor.currentView.state,
             from = state.selection.from,
             linkMark = state.selection.$from.marks().find(
-                mark => mark.type.name === 'link'
+                mark => mark.type.name === "link"
             )
         if (linkMark) {
-            if (linkMark.attrs.href[0] === '#') {
-                this.linkType = 'internal'
+            if (linkMark.attrs.href[0] === "#") {
+                this.linkType = "internal"
                 this.target = linkMark.attrs.href.slice(1)
             } else {
-                this.linkType = 'external'
+                this.linkType = "external"
                 this.target = linkMark.attrs.href
-                this.title = linkMark.attrs.title ? linkMark.attrs.title : ''
+                this.title = linkMark.attrs.title ? linkMark.attrs.title : ""
             }
             this.extendSelectionToMark(from, linkMark)
-            this.submitButtonText = gettext('Update')
+            this.submitButtonText = gettext("Update")
         }
     }
 
     // Check if the selection spans over exactly one cross reference node. If so, use it.
     checkCrossReference() {
         if (
-            this.editor.currentView.state.selection.node?.type.name === 'cross_reference'
+            this.editor.currentView.state.selection.node?.type.name === "cross_reference"
         ) {
-            this.submitButtonText = gettext('Update')
+            this.submitButtonText = gettext("Update")
             this.target = this.editor.currentView.state.selection.node.attrs.id
-            this.linkType = 'cross_reference'
+            this.linkType = "cross_reference"
         }
     }
 
@@ -74,14 +74,14 @@ export class LinkDialog {
         if (this.editor.currentView === this.editor.view) {
             const settings = this.editor.view.state.selection.$anchor.node(2).attrs
             return {
-                link: settings.marks.includes('link'),
-                cross_reference: settings.elements.includes('cross_reference')
+                link: settings.marks.includes("link"),
+                cross_reference: settings.elements.includes("cross_reference")
             }
         } else {
             const settings = this.editor.view.state.doc.firstChild.attrs
             return {
-                link: settings.footnote_marks.includes('link'),
-                cross_reference: settings.footnote_elements.includes('cross_reference')
+                link: settings.footnote_marks.includes("link"),
+                cross_reference: settings.footnote_elements.includes("cross_reference")
             }
         }
 
@@ -120,37 +120,37 @@ export class LinkDialog {
         const buttons = []
         buttons.push({
             text: this.submitButtonText,
-            classes: 'fw-dark',
+            classes: "fw-dark",
             click: () => {
-                const linkTypeEl = this.dialog.dialogEl.querySelector('input[name=link-type]:checked'),
-                    linkType = linkTypeEl ? linkTypeEl.value : 'external'
+                const linkTypeEl = this.dialog.dialogEl.querySelector("input[name=link-type]:checked"),
+                    linkType = linkTypeEl ? linkTypeEl.value : "external"
                 let href, title, target, change
 
                 switch (linkType) {
-                case 'internal': {
-                    target = this.dialog.dialogEl.querySelector('select.internal-link-selector').value
+                case "internal": {
+                    target = this.dialog.dialogEl.querySelector("select.internal-link-selector").value
                     href = `#${target}`
                     title = this.internalTargets.find(iTarget => iTarget.id === target).text
-                    change = target && (this.linkType !== 'internal' || this.target !== target)
+                    change = target && (this.linkType !== "internal" || this.target !== target)
                     break
                 }
-                case 'external': {
-                    const linkEl = this.dialog.dialogEl.querySelector('input.link')
+                case "external": {
+                    const linkEl = this.dialog.dialogEl.querySelector("input.link")
                     if (!(new RegExp(/^\s*$/)).test(linkEl.value) && linkEl.value !== this.defaultLink) {
                         href = linkEl.value
                     }
-                    title = this.dialog.dialogEl.querySelector('input.link-title').value
+                    title = this.dialog.dialogEl.querySelector("input.link-title").value
                     if ((new RegExp(/^\s*$/)).test(title)) {
                         // The link title is empty. Make it the same as the link itself.
                         title = href
                     }
-                    change = href && (this.linkType !== 'external' || this.target !== href || this.title !== title)
+                    change = href && (this.linkType !== "external" || this.target !== href || this.title !== title)
                     break
                 }
-                case 'cross_reference': {
-                    target = this.dialog.dialogEl.querySelector('select.cross-reference-selector').value
+                case "cross_reference": {
+                    target = this.dialog.dialogEl.querySelector("select.cross-reference-selector").value
                     title = this.internalTargets.find(iTarget => iTarget.id === target).text
-                    change = target && (this.linkType !== 'cross_reference' || this.target !== target)
+                    change = target && (this.linkType !== "cross_reference" || this.target !== target)
                     break
                 }
                 }
@@ -168,7 +168,7 @@ export class LinkDialog {
                     tr = view.state.tr
                 let posTo = view.state.selection.to
 
-                if (linkType === 'cross_reference') {
+                if (linkType === "cross_reference") {
                     const node = view.state.schema.nodes.cross_reference.create({id: target, title})
                     tr.replaceSelectionWith(node)
                 } else {
@@ -196,11 +196,11 @@ export class LinkDialog {
         })
 
         buttons.push({
-            type: 'cancel'
+            type: "cancel"
         })
 
         this.dialog = new Dialog({
-            id: 'edit-link',
+            id: "edit-link",
             title: gettext("Link"),
             body: linkDialogTemplate({
                 target: this.target,
@@ -219,29 +219,29 @@ export class LinkDialog {
         this.dialog.open()
 
         if (this.internalTargets.length) {
-            const externalEls = this.dialog.dialogEl.querySelectorAll('input.link, input.link-title'),
-                internalEls = this.dialog.dialogEl.querySelectorAll('select.internal-link-selector'),
-                crossReferenceEls = this.dialog.dialogEl.querySelectorAll('select.cross-reference-selector'),
-                externalSwitchers = this.dialog.dialogEl.querySelectorAll('input.link, input.link-title, label.link-external-label, input.link-external-check'),
-                internalSwitchers = this.dialog.dialogEl.querySelectorAll('select.internal-link-selector, label.link-internal-label, input.link-internal-check'),
-                crossReferenceSwitchers = this.dialog.dialogEl.querySelectorAll('select.cross-reference-selector, label.cross-reference-label, input.cross-reference-check'),
-                radioInternal = this.dialog.dialogEl.querySelector('input.link-internal-check'),
-                radioExternal = this.dialog.dialogEl.querySelector('input.link-external-check'),
-                radioCrossReference = this.dialog.dialogEl.querySelector('input.cross-reference-check')
+            const externalEls = this.dialog.dialogEl.querySelectorAll("input.link, input.link-title"),
+                internalEls = this.dialog.dialogEl.querySelectorAll("select.internal-link-selector"),
+                crossReferenceEls = this.dialog.dialogEl.querySelectorAll("select.cross-reference-selector"),
+                externalSwitchers = this.dialog.dialogEl.querySelectorAll("input.link, input.link-title, label.link-external-label, input.link-external-check"),
+                internalSwitchers = this.dialog.dialogEl.querySelectorAll("select.internal-link-selector, label.link-internal-label, input.link-internal-check"),
+                crossReferenceSwitchers = this.dialog.dialogEl.querySelectorAll("select.cross-reference-selector, label.cross-reference-label, input.cross-reference-check"),
+                radioInternal = this.dialog.dialogEl.querySelector("input.link-internal-check"),
+                radioExternal = this.dialog.dialogEl.querySelector("input.link-external-check"),
+                radioCrossReference = this.dialog.dialogEl.querySelector("input.cross-reference-check")
 
 
             switch (this.linkType) {
-            case 'internal':
+            case "internal":
                 externalEls.forEach(el => el.classList.add("disabled"))
                 crossReferenceEls.forEach(el => el.classList.add("disabled"))
                 radioInternal.checked = true
                 break
-            case 'external':
+            case "external":
                 internalEls.forEach(el => el.classList.add("disabled"))
                 externalEls.forEach(el => el.classList.add("disabled"))
                 radioExternal.checked = true
                 break
-            case 'cross_reference':
+            case "cross_reference":
                 internalEls.forEach(el => el.classList.add("disabled"))
                 crossReferenceEls.forEach(el => el.classList.add("disabled"))
                 radioCrossReference.checked = true
@@ -250,21 +250,21 @@ export class LinkDialog {
                 break
             }
 
-            internalSwitchers.forEach(el => el.addEventListener('click', () => {
+            internalSwitchers.forEach(el => el.addEventListener("click", () => {
                 externalEls.forEach(el => el.classList.add("disabled"))
                 internalEls.forEach(el => el.classList.remove("disabled"))
                 crossReferenceEls.forEach(el => el.classList.add("disabled"))
                 radioInternal.checked = true
             }))
 
-            externalSwitchers.forEach(el => el.addEventListener('click', () => {
+            externalSwitchers.forEach(el => el.addEventListener("click", () => {
                 internalEls.forEach(el => el.classList.add("disabled"))
                 externalEls.forEach(el => el.classList.remove("disabled"))
                 crossReferenceEls.forEach(el => el.classList.add("disabled"))
                 radioExternal.checked = true
             }))
 
-            crossReferenceSwitchers.forEach(el => el.addEventListener('click', () => {
+            crossReferenceSwitchers.forEach(el => el.addEventListener("click", () => {
                 internalEls.forEach(el => el.classList.add("disabled"))
                 externalEls.forEach(el => el.classList.add("disabled"))
                 crossReferenceEls.forEach(el => el.classList.remove("disabled"))
