@@ -1,5 +1,7 @@
 import {mathDialogTemplate} from "./templates"
 import {Dialog} from "../../common"
+import {sub, sup, subChars, supChars} from "./subsup"
+
 
 /**
  * Class to work with formula dialog
@@ -9,7 +11,7 @@ export class MathDialog {
         this.editor = editor
         this.node = this.editor.currentView.state.selection.node
         this.equationSelected = this.node && this.node.attrs && this.node.attrs.equation ? true : false
-        this.equation = this.equationSelected ? this.node.attrs.equation : ''
+        this.equation = this.equationSelected ? this.node.attrs.equation : ""
     }
 
     init() {
@@ -21,8 +23,8 @@ export class MathDialog {
             height: 100,
             buttons: [
                 {
-                    text: this.equationSelected ? gettext('Update') : gettext('Insert'),
-                    classes: 'fw-dark insert-math',
+                    text: this.equationSelected ? gettext("Update") : gettext("Insert"),
+                    classes: "fw-dark insert-math",
                     click: () => {
                         const view = this.editor.currentView,
                             state = view.state
@@ -36,12 +38,32 @@ export class MathDialog {
                             }
                             this.dialog.close()
                             return
+                        } else if (
+                            (new RegExp(`^\\^({[${supChars}]*}|[${supChars}]?)$`)
+                            ).test(this.equation)) {
+                            // The math input is pure superscript and
+                            // can be converted to ordinary characters.
+                            view.dispatch(
+                                state.tr.insertText(sup(this.equation.slice(1)))
+                            )
+                            this.dialog.close()
+                            return
+                        } else if (
+                            (new RegExp(`^\\_({[${subChars}]*}|[${subChars}]?)$`)
+                            ).test(this.equation)) {
+                            // The math input is pure subscript and
+                            // can be converted to ordinary characters.
+                            view.dispatch(
+                                state.tr.insertText(sub(this.equation.slice(1)))
+                            )
+                            this.dialog.close()
+                            return
                         } else if (this.equationSelected && this.equation === this.node.attrs.equation) {
                             // Equation selected, but has not changed from last time.
                             this.dialog.close()
                             return
                         }
-                        const nodeType = state.schema.nodes['equation']
+                        const nodeType = state.schema.nodes["equation"]
                         view.dispatch(
                             state.tr.replaceSelectionWith(nodeType.createAndFill({
                                 equation: this.equation
@@ -51,16 +73,16 @@ export class MathDialog {
                     }
                 },
                 {
-                    type: 'cancel'
+                    type: "cancel"
                 }
             ],
-            title: gettext('Mathematical formula'),
+            title: gettext("Mathematical formula"),
             beforeClose: () => {
                 if (this.mathField) {
                     this.mathField = false
                 }
             },
-            classes: 'math',
+            classes: "math",
             onClose: () => this.editor.currentView.focus()
         })
         this.dialog.open()
@@ -68,11 +90,13 @@ export class MathDialog {
         this.mathliveDOM = this.dialog.dialogEl.querySelector(".math-field")
 
         import("mathlive").then(MathLive => {
-            this.mathField = MathLive.makeMathField(this.mathliveDOM, {
-                virtualKeyboardMode: 'onfocus',
-                locale: 'int',
+            this.mathField = new MathLive.MathfieldElement({
+                virtualKeyboardMode: "onfocus",
+                keypressSound: null,
+                plonkSound: null,
+                locale: "int",
                 strings: {
-                    'int': {
+                    "int": {
                         "keyboard.tooltip.functions": gettext("Functions"),
                         "keyboard.tooltip.greek": gettext("Greek Letters"),
                         "keyboard.tooltip.command": gettext("LaTeX Command Mode"),
@@ -85,7 +109,8 @@ export class MathDialog {
                     }
                 }
             })
-            this.mathField.setValue(this.equation)
+            this.mathField.value = this.equation
+            this.mathliveDOM.appendChild(this.mathField)
         })
     }
 
