@@ -1,27 +1,27 @@
 export const navigatorFilterModel = () => ({
     content: [
         {
-            title: gettext('Heading 1'),
+            title: gettext("Heading 1"),
             level: 1
         },
         {
-            title: gettext('Heading 2'),
+            title: gettext("Heading 2"),
             level: 2
         },
         {
-            title: gettext('Heading 3'),
+            title: gettext("Heading 3"),
             level: 3
         },
         {
-            title: gettext('Heading 4'),
+            title: gettext("Heading 4"),
             level: 4
         },
         {
-            title: gettext('Heading 5'),
+            title: gettext("Heading 5"),
             level: 5
         },
         {
-            title: gettext('Heading 6'),
+            title: gettext("Heading 6"),
             level: 6
         }
     ]
