@@ -43,24 +43,24 @@ const tableAddedFromTemplate = function(state) {
 }
 
 const tableAddedByUser = function(table, userId) {
-    return table.attrs.track.find(track => (track.type === 'insertion' && track.user === userId)) ? true : false
+    return table.attrs.track.find(track => (track.type === "insertion" && track.user === userId)) ? true : false
 }
 export const tableMenuModel = () => ({
     content: [
         {
-            title: editor => `${gettext('Add row above')}${editor.view.state.doc.firstChild.attrs.tracked ? ` (${gettext('Not tracked')})` : ''}`,
-            type: 'action',
-            tooltip: gettext('Add a row above the current row'),
+            title: editor => `${gettext("Add row above")}${editor.view.state.doc.firstChild.attrs.tracked ? ` (${gettext("Not tracked")})` : ""}`,
+            type: "action",
+            tooltip: gettext("Add a row above the current row"),
             order: 0,
             action: editor => {
-                addRowBefore(editor.currentView.state, tr => editor.currentView.dispatch(tr.setMeta('untracked', true)))
+                addRowBefore(editor.currentView.state, tr => editor.currentView.dispatch(tr.setMeta("untracked", true)))
             },
             disabled: editor => {
                 const table = findTable(editor.currentView.state)
                 if (
                     !table ||
                     (
-                        ['write-tracked', 'review-tracked'].includes(editor.docInfo.access_rights) &&
+                        ["write-tracked", "review-tracked"].includes(editor.docInfo.access_rights) &&
                         !tableAddedByUser(table, editor.user.id)
                     )
                 ) {
@@ -71,19 +71,19 @@ export const tableMenuModel = () => ({
             }
         },
         {
-            title: editor => `${gettext('Add row below')}${editor.view.state.doc.firstChild.attrs.tracked ? ` (${gettext('Not tracked')})` : ''}`,
-            type: 'action',
-            tooltip: gettext('Add a row below the current row'),
+            title: editor => `${gettext("Add row below")}${editor.view.state.doc.firstChild.attrs.tracked ? ` (${gettext("Not tracked")})` : ""}`,
+            type: "action",
+            tooltip: gettext("Add a row below the current row"),
             order: 1,
             action: editor => {
-                addRowAfter(editor.currentView.state, tr => editor.currentView.dispatch(tr.setMeta('untracked', true)))
+                addRowAfter(editor.currentView.state, tr => editor.currentView.dispatch(tr.setMeta("untracked", true)))
             },
             disabled: editor => {
                 const table = findTable(editor.currentView.state)
                 if (
                     !table ||
                     (
-                        ['write-tracked', 'review-tracked'].includes(editor.docInfo.access_rights) &&
+                        ["write-tracked", "review-tracked"].includes(editor.docInfo.access_rights) &&
                         !tableAddedByUser(table, editor.user.id)
                     )
                 ) {
@@ -94,19 +94,19 @@ export const tableMenuModel = () => ({
             }
         },
         {
-            title: editor => `${gettext('Add column left')}${editor.view.state.doc.firstChild.attrs.tracked ? ` (${gettext('Not tracked')})` : ''}`,
-            type: 'action',
-            tooltip: gettext('Add a column to the left of the current column'),
+            title: editor => `${gettext("Add column left")}${editor.view.state.doc.firstChild.attrs.tracked ? ` (${gettext("Not tracked")})` : ""}`,
+            type: "action",
+            tooltip: gettext("Add a column to the left of the current column"),
             order: 2,
             action: editor => {
-                addColumnBefore(editor.currentView.state, tr => editor.currentView.dispatch(tr.setMeta('untracked', true)))
+                addColumnBefore(editor.currentView.state, tr => editor.currentView.dispatch(tr.setMeta("untracked", true)))
             },
             disabled: editor => {
                 const table = findTable(editor.currentView.state)
                 if (
                     !table ||
                     (
-                        ['write-tracked', 'review-tracked'].includes(editor.docInfo.access_rights) &&
+                        ["write-tracked", "review-tracked"].includes(editor.docInfo.access_rights) &&
                         !tableAddedByUser(table, editor.user.id)
                     )
                 ) {
@@ -117,19 +117,19 @@ export const tableMenuModel = () => ({
             }
         },
         {
-            title: editor => `${gettext('Add column right')}${editor.view.state.doc.firstChild.attrs.tracked ? ` (${gettext('Not tracked')})` : ''}`,
-            type: 'action',
-            tooltip: gettext('Add a column to the right of the current column'),
+            title: editor => `${gettext("Add column right")}${editor.view.state.doc.firstChild.attrs.tracked ? ` (${gettext("Not tracked")})` : ""}`,
+            type: "action",
+            tooltip: gettext("Add a column to the right of the current column"),
             order: 3,
             action: editor => {
-                addColumnAfter(editor.currentView.state, tr => editor.currentView.dispatch(tr.setMeta('untracked', true)))
+                addColumnAfter(editor.currentView.state, tr => editor.currentView.dispatch(tr.setMeta("untracked", true)))
             },
             disabled: editor => {
                 const table = findTable(editor.currentView.state)
                 if (
                     !table ||
                     (
-                        ['write-tracked', 'review-tracked'].includes(editor.docInfo.access_rights) &&
+                        ["write-tracked", "review-tracked"].includes(editor.docInfo.access_rights) &&
                         !tableAddedByUser(table, editor.user.id)
                     )
                 ) {
@@ -140,23 +140,23 @@ export const tableMenuModel = () => ({
             }
         },
         {
-            type: 'separator',
+            type: "separator",
             order: 4
         },
         {
-            title: editor => `${gettext('Delete row')}${editor.view.state.doc.firstChild.attrs.tracked ? ` (${gettext('Not tracked')})` : ''}`,
-            type: 'action',
-            tooltip: gettext('Delete current row'),
+            title: editor => `${gettext("Delete row")}${editor.view.state.doc.firstChild.attrs.tracked ? ` (${gettext("Not tracked")})` : ""}`,
+            type: "action",
+            tooltip: gettext("Delete current row"),
             order: 5,
             action: editor => {
-                deleteRow(editor.currentView.state, tr => editor.currentView.dispatch(tr.setMeta('untracked', true)))
+                deleteRow(editor.currentView.state, tr => editor.currentView.dispatch(tr.setMeta("untracked", true)))
             },
             disabled: editor => {
                 const table = findTable(editor.currentView.state)
                 if (
                     !table ||
                     (
-                        ['write-tracked', 'review-tracked'].includes(editor.docInfo.access_rights) &&
+                        ["write-tracked", "review-tracked"].includes(editor.docInfo.access_rights) &&
                         !tableAddedByUser(table, editor.user.id)
                     )
                 ) {
@@ -167,19 +167,19 @@ export const tableMenuModel = () => ({
             }
         },
         {
-            title: editor => `${gettext('Delete column')}${editor.view.state.doc.firstChild.attrs.tracked ? ` (${gettext('Not tracked')})` : ''}`,
-            type: 'action',
-            tooltip: gettext('Delete current column'),
+            title: editor => `${gettext("Delete column")}${editor.view.state.doc.firstChild.attrs.tracked ? ` (${gettext("Not tracked")})` : ""}`,
+            type: "action",
+            tooltip: gettext("Delete current column"),
             order: 6,
             action: editor => {
-                deleteColumn(editor.currentView.state, tr => editor.currentView.dispatch(tr.setMeta('untracked', true)))
+                deleteColumn(editor.currentView.state, tr => editor.currentView.dispatch(tr.setMeta("untracked", true)))
             },
             disabled: editor => {
                 const table = findTable(editor.currentView.state)
                 if (
                     !table ||
                     (
-                        ['write-tracked', 'review-tracked'].includes(editor.docInfo.access_rights) &&
+                        ["write-tracked", "review-tracked"].includes(editor.docInfo.access_rights) &&
                         !tableAddedByUser(table, editor.user.id)
                     )
                 ) {
@@ -190,26 +190,26 @@ export const tableMenuModel = () => ({
             }
         },
         {
-            type: 'separator',
+            type: "separator",
             order: 7,
         },
         {
-            title: editor => `${gettext('Merge cells')}${editor.view.state.doc.firstChild.attrs.tracked ? ` (${gettext('Not tracked')})` : ''}`,
-            type: 'action',
-            tooltip: gettext('Merge selected cells'),
+            title: editor => `${gettext("Merge cells")}${editor.view.state.doc.firstChild.attrs.tracked ? ` (${gettext("Not tracked")})` : ""}`,
+            type: "action",
+            tooltip: gettext("Merge selected cells"),
             order: 8,
             action: editor => {
-                mergeCells(editor.currentView.state, tr => editor.currentView.dispatch(tr.setMeta('untracked', true)))
+                mergeCells(editor.currentView.state, tr => editor.currentView.dispatch(tr.setMeta("untracked", true)))
             },
             disabled: editor => {
                 const table = findTable(editor.currentView.state)
                 if (
                     !table ||
-                    editor.currentView.state.selection.jsonID !== 'cell' ||
+                    editor.currentView.state.selection.jsonID !== "cell" ||
                     editor.currentView.state.selection.$headCell.pos ===
                     editor.currentView.state.selection.$anchorCell.pos ||
                     (
-                        ['write-tracked', 'review-tracked'].includes(editor.docInfo.access_rights) &&
+                        ["write-tracked", "review-tracked"].includes(editor.docInfo.access_rights) &&
                         !tableAddedByUser(table, editor.user.id)
                     )
                 ) {
@@ -221,18 +221,18 @@ export const tableMenuModel = () => ({
 
         },
         {
-            title: editor => `${gettext('Split cells')}${editor.view.state.doc.firstChild.attrs.tracked ? ` (${gettext('Not tracked')})` : ''}`,
-            type: 'action',
-            tooltip: gettext('Split selected cell'),
+            title: editor => `${gettext("Split cells")}${editor.view.state.doc.firstChild.attrs.tracked ? ` (${gettext("Not tracked")})` : ""}`,
+            type: "action",
+            tooltip: gettext("Split selected cell"),
             order: 9,
             action: editor => {
-                splitCell(editor.currentView.state, tr => editor.currentView.dispatch(tr.setMeta('untracked', true)))
+                splitCell(editor.currentView.state, tr => editor.currentView.dispatch(tr.setMeta("untracked", true)))
             },
             disabled: editor => {
                 const table = findTable(editor.currentView.state)
                 if (
                     !table ||
-                    editor.currentView.state.selection.jsonID !== 'cell' ||
+                    editor.currentView.state.selection.jsonID !== "cell" ||
                     editor.currentView.state.selection.$headCell.pos !==
                     editor.currentView.state.selection.$anchorCell.pos ||
                     (
@@ -240,7 +240,7 @@ export const tableMenuModel = () => ({
                         editor.currentView.state.selection.$anchorCell.nodeAfter.attrs.colspan === 1
                     ) ||
                     (
-                        ['write-tracked', 'review-tracked'].includes(editor.docInfo.access_rights) &&
+                        ["write-tracked", "review-tracked"].includes(editor.docInfo.access_rights) &&
                         !tableAddedByUser(table, editor.user.id)
                     )
                 ) {
@@ -251,13 +251,13 @@ export const tableMenuModel = () => ({
             }
         },
         {
-            type: 'separator',
+            type: "separator",
             order: 10,
         },
         {
-            title: editor => `${gettext('Toggle header row')}${editor.view.state.doc.firstChild.attrs.tracked ? ` (${gettext('Not tracked')})` : ''}`,
-            type: 'action',
-            tooltip: gettext('Toggle header-status of currently selected row'),
+            title: editor => `${gettext("Toggle header row")}${editor.view.state.doc.firstChild.attrs.tracked ? ` (${gettext("Not tracked")})` : ""}`,
+            type: "action",
+            tooltip: gettext("Toggle header-status of currently selected row"),
             order: 11,
             action: editor => {
                 toggleHeaderRow(editor.currentView.state, editor.currentView.dispatch)
@@ -267,7 +267,7 @@ export const tableMenuModel = () => ({
                 if (
                     !table ||
                     (
-                        ['write-tracked', 'review-tracked'].includes(editor.docInfo.access_rights) &&
+                        ["write-tracked", "review-tracked"].includes(editor.docInfo.access_rights) &&
                         !tableAddedByUser(table, editor.user.id)
                     )
                 ) {
@@ -278,9 +278,9 @@ export const tableMenuModel = () => ({
             }
         },
         {
-            title: editor => `${gettext('Toggle header column')}${editor.view.state.doc.firstChild.attrs.tracked ? ` (${gettext('Not tracked')})` : ''}`,
-            type: 'action',
-            tooltip: gettext('Toggle header-status of currently selected column'),
+            title: editor => `${gettext("Toggle header column")}${editor.view.state.doc.firstChild.attrs.tracked ? ` (${gettext("Not tracked")})` : ""}`,
+            type: "action",
+            tooltip: gettext("Toggle header-status of currently selected column"),
             order: 12,
             action: editor => {
                 toggleHeaderColumn(editor.currentView.state, editor.currentView.dispatch)
@@ -290,7 +290,7 @@ export const tableMenuModel = () => ({
                 if (
                     !table ||
                     (
-                        ['write-tracked', 'review-tracked'].includes(editor.docInfo.access_rights) &&
+                        ["write-tracked", "review-tracked"].includes(editor.docInfo.access_rights) &&
                         !tableAddedByUser(table, editor.user.id)
                     )
                 ) {
@@ -301,9 +301,9 @@ export const tableMenuModel = () => ({
             }
         },
         {
-            title: editor => `${gettext('Toggle header cell')}${editor.view.state.doc.firstChild.attrs.tracked ? ` (${gettext('Not tracked')})` : ''}`,
-            type: 'action',
-            tooltip: gettext('Toggle header-status of currently selected cells'),
+            title: editor => `${gettext("Toggle header cell")}${editor.view.state.doc.firstChild.attrs.tracked ? ` (${gettext("Not tracked")})` : ""}`,
+            type: "action",
+            tooltip: gettext("Toggle header-status of currently selected cells"),
             order: 13,
             action: editor => {
                 toggleHeaderCell(editor.currentView.state, editor.currentView.dispatch)
@@ -313,7 +313,7 @@ export const tableMenuModel = () => ({
                 if (
                     !table ||
                     (
-                        ['write-tracked', 'review-tracked'].includes(editor.docInfo.access_rights) &&
+                        ["write-tracked", "review-tracked"].includes(editor.docInfo.access_rights) &&
                         !tableAddedByUser(table, editor.user.id)
                     )
                 ) {
@@ -324,13 +324,13 @@ export const tableMenuModel = () => ({
             }
         },
         {
-            type: 'separator',
+            type: "separator",
             order: 14,
         },
         {
-            title: `${gettext('Configure')} ...`,
-            type: 'action',
-            tooltip: gettext('Configure the table.'),
+            title: `${gettext("Configure")} ...`,
+            type: "action",
+            tooltip: gettext("Configure the table."),
             order: 15,
             action: editor => {
                 const dialog = new TableConfigurationDialog(editor)
@@ -340,10 +340,10 @@ export const tableMenuModel = () => ({
             disabled: editor => !findTable(editor.currentView.state)
         },
         {
-            title: gettext('Delete table'),
-            type: 'action',
-            icon: 'trash-alt',
-            tooltip: gettext('Delete currently selected table'),
+            title: gettext("Delete table"),
+            type: "action",
+            icon: "trash-alt",
+            tooltip: gettext("Delete currently selected table"),
             order: 16,
             action: editor => {
                 deleteTable(editor.currentView.state, editor.currentView.dispatch)
