@@ -2,21 +2,21 @@ import {Plugin, PluginKey} from "prosemirror-state"
 import {Fragment} from "prosemirror-model"
 
 
-const key = new PluginKey('documentTemplate')
+const key = new PluginKey("documentTemplate")
 
 export function addDeletedPartWidget(dom, view, getPos) {
-    dom.classList.add('article-deleted')
+    dom.classList.add("article-deleted")
     dom.insertAdjacentHTML(
-        'beforeend',
-        '<div class="remove-article-part"><i class="fa fa-trash-alt"></i></div>'
+        "beforeend",
+        "<div class=\"remove-article-part\"><i class=\"fa fa-trash-alt\"></i></div>"
     )
     const removeButton = dom.lastElementChild
-    removeButton.addEventListener('click', () => {
+    removeButton.addEventListener("click", () => {
         const from = getPos(),
             to = from + view.state.doc.nodeAt(from).nodeSize,
             tr = view.state.tr
         tr.delete(from, to)
-        tr.setMeta('deleteUnusedSection', true)
+        tr.setMeta("deleteUnusedSection", true)
         view.dispatch(tr)
     })
 }
@@ -32,7 +32,7 @@ export function checkProtectedInSelection(state) {
 
     // If the protection is of header/start check if selection falls within the
     // protected range
-    if (['start', 'header'].includes(anchorDocPart.attrs.locking) || ['start', 'header'].includes(headDocPart.attrs.locking)) {
+    if (["start", "header"].includes(anchorDocPart.attrs.locking) || ["start", "header"].includes(headDocPart.attrs.locking)) {
         const protectedRanges = key.getState(state).protectedRanges,
             start = state.selection.from,
             end = state.selection.to
@@ -51,15 +51,15 @@ export class PartView {
         this.node = node
         this.view = view
         this.getPos = getPos
-        this.dom = document.createElement('div')
-        this.dom.classList.add('article-part')
+        this.dom = document.createElement("div")
+        this.dom.classList.add("article-part")
         this.dom.classList.add(`article-${this.node.type.name}`)
         this.dom.classList.add(`article-${this.node.attrs.id}`)
         if (node.attrs.hidden) {
             this.dom.dataset.hidden = true
         }
         if (node.attrs.deleted) {
-            this.contentDOM = this.dom.appendChild(document.createElement('div'))
+            this.contentDOM = this.dom.appendChild(document.createElement("div"))
             addDeletedPartWidget(this.dom, view, getPos)
         } else {
             this.contentDOM = this.dom
@@ -76,18 +76,18 @@ export const documentTemplatePlugin = function(options) {
         key,
         state: {
             init(config, state) {
-                if (options.editor.docInfo.access_rights === 'write') {
-                    this.spec.props.nodeViews['richtext_part'] = (node, view, getPos) => new PartView(
+                if (options.editor.docInfo.access_rights === "write") {
+                    this.spec.props.nodeViews["richtext_part"] = (node, view, getPos) => new PartView(
                         node,
                         view,
                         getPos
                     )
-                    this.spec.props.nodeViews['heading_part'] = (node, view, getPos) => new PartView(
+                    this.spec.props.nodeViews["heading_part"] = (node, view, getPos) => new PartView(
                         node,
                         view,
                         getPos
                     )
-                    this.spec.props.nodeViews['table_part'] = (node, view, getPos) => new PartView(
+                    this.spec.props.nodeViews["table_part"] = (node, view, getPos) => new PartView(
                         node,
                         view,
                         getPos
@@ -102,11 +102,11 @@ export const documentTemplatePlugin = function(options) {
                 state.doc.firstChild.forEach((node, pos) => {
                     const from = pos + 1 // + 1 to get inside the article node
                     let to = from + 1 // + 1 for the part node
-                    if (node.attrs.locking === 'fixed') {
+                    if (node.attrs.locking === "fixed") {
                         to = from + node.nodeSize
-                    } else if (node.attrs.locking === 'header') { // only relevant for tables
+                    } else if (node.attrs.locking === "header") { // only relevant for tables
                         to = from + 1 + 1 + 1 + node.firstChild.firstChild.nodeSize // + 1 for the part node + 1 for the table + 1 for the first row
-                    } else if (node.attrs.locking === 'start') {
+                    } else if (node.attrs.locking === "start") {
                         let initialFragment = Fragment.fromJSON(options.editor.schema, node.attrs.initial)
                         let protectionSize = initialFragment.size
                         if (initialFragment.lastChild?.isTextblock) {
@@ -155,13 +155,13 @@ export const documentTemplatePlugin = function(options) {
         filterTransaction: (tr, state) => {
             if (
                 !tr.docChanged ||
-                tr.getMeta('fixIds') ||
-                tr.getMeta('remote') ||
-                tr.getMeta('track') ||
-                tr.getMeta('fromFootnote') ||
-                tr.getMeta('deleteUnusedSection') ||
-                tr.getMeta('settings') ||
-                ['historyUndo', 'historyRedo'].includes(tr.getMeta('inputType'))
+                tr.getMeta("fixIds") ||
+                tr.getMeta("remote") ||
+                tr.getMeta("track") ||
+                tr.getMeta("fromFootnote") ||
+                tr.getMeta("deleteUnusedSection") ||
+                tr.getMeta("settings") ||
+                ["historyUndo", "historyRedo"].includes(tr.getMeta("inputType"))
             ) {
                 return true
             }
@@ -184,7 +184,7 @@ export const documentTemplatePlugin = function(options) {
                         {start: mapInv.map(range.start, -1), end: mapInv.map(range.end, 1)}
                     ))
                 }
-                if (['removeMark', 'addMark'].includes(step.jsonID)) {
+                if (["removeMark", "addMark"].includes(step.jsonID)) {
                     changingRanges.push({start: step.from, end: step.to})
                 }
                 map.forEach((start, end) => {
@@ -206,10 +206,10 @@ export const documentTemplatePlugin = function(options) {
             changingRanges.forEach(range => state.doc.nodesBetween(range.from, range.to, (node, pos, parent, _index) => {
                 if (parent === tr.doc.firstChild) {
                     allowedElements = node.attrs.elements ?
-                        node.attrs.elements.concat('table_row', 'table_cell', 'table_header', 'list_item', 'text') :
+                        node.attrs.elements.concat("table_row", "table_cell", "table_header", "list_item", "text") :
                         false
                     allowedMarks = node.attrs.marks ?
-                        node.attrs.marks.concat('insertion', 'deletion', 'comment', 'anchor') :
+                        node.attrs.marks.concat("insertion", "deletion", "comment", "anchor") :
                         false
                     return allowed
                 }
