@@ -1,6 +1,6 @@
 import {Plugin, PluginKey} from "prosemirror-state"
 
-const key = new PluginKey('marginboxes')
+const key = new PluginKey("marginboxes")
 export const marginboxesPlugin = function(options) {
     return new Plugin({
         key,
