@@ -19,15 +19,15 @@ export function findSelectedChanges(state) {
     if (selection.empty) {
         const resolvedPos = state.doc.resolve(selection.from), marks = resolvedPos.marks()
         if (marks) {
-            insertionMark = marks.find(mark => mark.type.name === 'insertion' && !mark.attrs.approved)
+            insertionMark = marks.find(mark => mark.type.name === "insertion" && !mark.attrs.approved)
             if (insertionMark) {
                 insertionPos = selection.from
             }
-            deletionMark = marks.find(mark => mark.type.name === 'deletion')
+            deletionMark = marks.find(mark => mark.type.name === "deletion")
             if (deletionMark) {
                 deletionPos = selection.from
             }
-            formatChangeMark = marks.find(mark => mark.type.name === 'format_change')
+            formatChangeMark = marks.find(mark => mark.type.name === "format_change")
             if (formatChangeMark) {
                 formatChangePos = selection.from
             }
@@ -42,8 +42,8 @@ export function findSelectedChanges(state) {
                 }
                 if (!insertionMark) {
                     insertionMark = node.attrs.track ?
-                        node.attrs.track.find(trackAttr => trackAttr.type === 'insertion') :
-                        node.marks.find(mark => mark.type.name === 'insertion' && !mark.attrs.approved)
+                        node.attrs.track.find(trackAttr => trackAttr.type === "insertion") :
+                        node.marks.find(mark => mark.type.name === "insertion" && !mark.attrs.approved)
                     if (insertionMark) {
                         insertionPos = pos
                         if (!node.isInline) {
@@ -53,8 +53,8 @@ export function findSelectedChanges(state) {
                 }
                 if (!deletionMark) {
                     deletionMark = node.attrs.track ?
-                        node.attrs.track.find(trackAttr => trackAttr.type === 'deletion') :
-                        node.marks.find(mark => mark.type.name === 'deletion')
+                        node.attrs.track.find(trackAttr => trackAttr.type === "deletion") :
+                        node.marks.find(mark => mark.type.name === "deletion")
                     if (deletionMark) {
                         deletionPos = pos
                         if (!node.isInline) {
@@ -63,7 +63,7 @@ export function findSelectedChanges(state) {
                     }
                 }
                 if (!formatChangeMark) {
-                    formatChangeMark = node.marks.find(mark => mark.type.name === 'format_change')
+                    formatChangeMark = node.marks.find(mark => mark.type.name === "format_change")
                     if (formatChangeMark) {
                         formatChangePos = pos
                         if (!node.isInline) {
