@@ -36,11 +36,11 @@ export class DocxExporterRels {
 
     // Go through a rels xml file and file all the listed relations
     findMaxRelId() {
-        const rels = this.xml.querySelectorAll('Relationship')
+        const rels = this.xml.querySelectorAll("Relationship")
 
         rels.forEach(
             rel => {
-                const id = parseInt(rel.getAttribute("Id").replace(/\D/g, ''))
+                const id = parseInt(rel.getAttribute("Id").replace(/\D/g, ""))
                 if (id > this.maxRelId) {
                     this.maxRelId = id
                 }
@@ -51,56 +51,56 @@ export class DocxExporterRels {
     addRelsToCt() {
         const override = this.ctXml.querySelector(`Override[PartName="/${this.filePath}"]`)
         if (!override) {
-            const types = this.ctXml.querySelector('Types')
-            types.insertAdjacentHTML('beforeEnd', `<Override PartName="/${this.filePath}" ContentType="application/vnd.openxmlformats-package.relationships+xml"/>`)
+            const types = this.ctXml.querySelector("Types")
+            types.insertAdjacentHTML("beforeEnd", `<Override PartName="/${this.filePath}" ContentType="application/vnd.openxmlformats-package.relationships+xml"/>`)
         }
     }
     // Add a relationship for a link
     addLinkRel(link) {
-        const rels = this.xml.querySelector('Relationships')
+        const rels = this.xml.querySelector("Relationships")
         const rId = this.maxRelId + 1
         const string = `<Relationship Id="rId${rId}" Type="http://schemas.openxmlformats.org/officeDocument/2006/relationships/hyperlink" Target="${escapeText(link)}" TargetMode="External"/>`
-        rels.insertAdjacentHTML('beforeEnd', string)
+        rels.insertAdjacentHTML("beforeEnd", string)
         this.maxRelId = rId
         return rId
     }
 
     // add a relationship for an image
     addImageRel(imgFileName) {
-        const rels = this.xml.querySelector('Relationships')
+        const rels = this.xml.querySelector("Relationships")
         const rId = this.maxRelId + 1
         const string = `<Relationship Id="rId${rId}" Type="http://schemas.openxmlformats.org/officeDocument/2006/relationships/image" Target="media/${escapeText(imgFileName)}"/>`
-        rels.insertAdjacentHTML('beforeEnd', string)
+        rels.insertAdjacentHTML("beforeEnd", string)
         this.maxRelId = rId
         return rId
     }
 
     addFootnoteRel() {
-        const footnotesRel = this.xml.querySelector('Relationship[Target="footnotes.xml"]')
+        const footnotesRel = this.xml.querySelector("Relationship[Target=\"footnotes.xml\"]")
         if (footnotesRel) {
             // Rel exists already
-            const fnRId = parseInt(footnotesRel.getAttribute('Id').replace(/\D/g, ''))
+            const fnRId = parseInt(footnotesRel.getAttribute("Id").replace(/\D/g, ""))
             return fnRId
         }
-        const rels = this.xml.querySelector('Relationships')
+        const rels = this.xml.querySelector("Relationships")
         const rId = this.maxRelId + 1
         const string = `<Relationship Id="rId${rId}" Type="http://schemas.openxmlformats.org/officeDocument/2006/relationships/footnotes" Target="footnotes.xml"/>`
-        rels.insertAdjacentHTML('beforeEnd', string)
+        rels.insertAdjacentHTML("beforeEnd", string)
         this.maxRelId = rId
         return rId
     }
 
     addNumberingRel() {
-        const numberingRel = this.xml.querySelector('Relationship[Target="numbering.xml"]')
+        const numberingRel = this.xml.querySelector("Relationship[Target=\"numbering.xml\"]")
         if (numberingRel) {
             // Rel exists already
-            const nuRId = parseInt(numberingRel.getAttribute('Id').replace(/\D/g, ''))
+            const nuRId = parseInt(numberingRel.getAttribute("Id").replace(/\D/g, ""))
             return nuRId
         }
-        const rels = this.xml.querySelector('Relationships')
+        const rels = this.xml.querySelector("Relationships")
         const rId = this.maxRelId + 1
         const string = `<Relationship Id="rId${rId}" Type="http://schemas.openxmlformats.org/officeDocument/2006/relationships/numbering" Target="numbering.xml"/>`
-        rels.insertAdjacentHTML('beforeEnd', string)
+        rels.insertAdjacentHTML("beforeEnd", string)
         this.maxRelId = rId
         return rId
     }
