@@ -15,6 +15,13 @@ module.exports = { // eslint-disable-line no-undef
             {
                 "importFrom": [process.env.SRC_PATH + "/base/static/css/colors.css"]
             }
-        ]
+        ],
+        "selector-class-pattern": [
+            "^(([a-z][a-z0-9]*)(-[a-z0-9]+)*)|(ProseMirror(-[a-z0-9]+)*)$",
+            {
+                message:
+					"Selector should use lowercase and separate words with hyphens (selector-class-pattern)",
+            },
+        ],
     }
-}
\ No newline at end of file
+}
