@@ -1,10 +1,9 @@
 import uuid
 
 from django.db import models
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 from django.contrib.contenttypes.fields import GenericRelation
 from django.contrib.auth.models import AbstractUser
-from django.core.files import File
 from avatar.utils import get_default_avatar_url
 
 from document.models import AccessRight
@@ -32,7 +31,7 @@ def auto_avatar(username):
 
 
 class User(AbstractUser):
-    contacts = models.ManyToManyField("self", symmetrical=True)
+    contacts = models.ManyToManyField("self", blank=True, symmetrical=True)
     document_rights = GenericRelation(
         "document.AccessRight",
         content_type_field="holder_type",
@@ -40,41 +39,6 @@ class User(AbstractUser):
         related_query_name="user",
     )
 
-    @property
-    def avatar_url(self):
-        size = 80
-        # We use our own method to find the avatar to instead of
-        # "get_primary_avatar" as this way we can minimize the reading from
-        # disk and set a default thumbnail in case we could not create one.
-        # See https://github.com/grantmcconnaughey/django-avatar/pull/187
-        avatar = self.avatar_set.order_by("-primary", "-date_uploaded").first()
-        if avatar:
-            if not avatar.thumbnail_exists(size):
-                avatar.create_thumbnail(size)
-                # Now check if the thumbnail was actually created
-                if not avatar.thumbnail_exists(size):
-                    # Thumbnail was not saved. There must be some PIL bug
-                    # with this image type. We store the original file instead.
-                    avatar.avatar.storage.save(
-                        avatar.avatar_name(size),
-                        File(
-                            avatar.avatar.storage.open(
-                                avatar.avatar.name, "rb"
-                            )
-                        ),
-                    )
-            url = avatar.avatar_url(size)
-            return {
-                "url": url,
-                "uploaded": True,
-                "html": (
-                    f'<img class="fw-avatar" src="{url}" '
-                    f'alt="{self.username}">'
-                ),
-            }
-        else:
-            return auto_avatar(self.username)
-
     @property
     def readable_name(self):
         readable_name = self.get_full_name()
