@@ -3,7 +3,7 @@ import {DataTable} from "simple-datatables"
 import {deleteContactCell, respondInviteCell, displayContactType} from "./templates"
 import {DeleteContactDialog} from "./delete_dialog"
 import {RespondInviteDialog} from "./respond_invite"
-import {postJson, addAlert, OverviewMenuView, findTarget, whenReady, baseBodyTemplate, setDocTitle, DatatableBulk, escapeText} from "../common"
+import {postJson, addAlert, OverviewMenuView, findTarget, whenReady, baseBodyTemplate, setDocTitle, DatatableBulk, escapeText, avatarTemplate} from "../common"
 import {FeedbackTab} from "../feedback"
 import {SiteMenu} from "../menu"
 import {menuModel, bulkMenuModel} from "./menu"
@@ -31,14 +31,15 @@ export class ContactsOverview {
     render() {
         this.dtBulk = new DatatableBulk(this, bulkMenuModel())
 
-        this.dom = document.createElement('body')
+        this.dom = document.createElement("body")
         this.dom.innerHTML = baseBodyTemplate({
-            contents: '',
+            contents: "",
             user: this.user,
-            hasOverview: true
+            hasOverview: true,
+            app: this.app
         })
         document.body = this.dom
-        setDocTitle(gettext('Contacts'), this.app)
+        setDocTitle(gettext("Contacts"), this.app)
         const feedbackTab = new FeedbackTab()
         feedbackTab.init()
 
@@ -50,12 +51,12 @@ export class ContactsOverview {
             this.table.destroy()
             this.table = false
         }
-        const tableEl = document.createElement('table')
-        tableEl.classList.add('fw-data-table')
-        tableEl.classList.add('fw-large')
-        tableEl.classList.add('contacts-table')
-        const contentsEl = document.querySelector('.fw-contents')
-        contentsEl.innerHTML = '' // Delete any old table
+        const tableEl = document.createElement("table")
+        tableEl.classList.add("fw-data-table")
+        tableEl.classList.add("fw-large")
+        tableEl.classList.add("contacts-table")
+        const contentsEl = document.querySelector(".fw-contents")
+        contentsEl.innerHTML = "" // Delete any old table
         contentsEl.appendChild(tableEl)
 
         this.dtBulk = new DatatableBulk(this, bulkMenuModel())
@@ -64,7 +65,8 @@ export class ContactsOverview {
             paging: false,
             scrollY: `${Math.max(window.innerHeight - 360, 100)}px`,
             labels: {
-                noRows: gettext("No contacts available") // Message shown when there are no search results
+                noRows: gettext("No contacts available"),
+                noResults: gettext("No contacts found") // Message shown when there are no search results
             },
             layout: {
                 top: "",
@@ -72,13 +74,13 @@ export class ContactsOverview {
             },
             data: {
                 headings: [
-                    '',
-                    '',
+                    "",
+                    "",
                     this.dtBulk.getHTML(),
                     gettext("Name"),
                     gettext("Type"),
                     gettext("Email address"),
-                    '',
+                    "",
                 ],
                 data: this.contacts.map(contact => this.createTableRow(contact))
             },
@@ -102,10 +104,10 @@ export class ContactsOverview {
             String(contact.id),
             contact.type,
             `<input type="checkbox" class="entry-select fw-check ${contact.type}" id="contact-${contact.type}-${contact.id}" data-id="${contact.id}" data-type="${contact.type}"><label for="contact-${contact.type}-${contact.id}"></label`,
-            `${contact.avatar.html} ${escapeText(contact.name)}`,
+            `${avatarTemplate({user: contact})} ${escapeText(contact.name)}`,
             displayContactType(contact),
             contact.email,
-            contact.type === 'to_userinvite' ? respondInviteCell(contact) : deleteContactCell(contact)
+            contact.type === "to_userinvite" ? respondInviteCell(contact) : deleteContactCell(contact)
         ]
     }
 
@@ -115,7 +117,7 @@ export class ContactsOverview {
         if (this.app.isOffline()) {
             return cachedPromise
         }
-        return postJson('/api/user/contacts/list/').then(
+        return postJson("/api/user/contacts/list/").then(
             ({json}) => {
                 return cachedPromise.then(oldJson => {
                     if (!deepEqual(json, oldJson)) {
@@ -129,7 +131,7 @@ export class ContactsOverview {
         ).catch(
             error => {
                 if (!this.app.isOffline()) {
-                    addAlert('error', gettext('Could not obtain contacts list'))
+                    addAlert("error", gettext("Could not obtain contacts list"))
                     throw (error)
                 }
             }
@@ -141,7 +143,9 @@ export class ContactsOverview {
     }
 
     initializeView() {
-        this.initTable()
+        if (this.app.page === this) {
+            this.initTable()
+        }
     }
 
     showCached() {
@@ -178,10 +182,10 @@ export class ContactsOverview {
     }
 
     bind() {
-        this.dom.addEventListener('click', event => {
+        this.dom.addEventListener("click", event => {
             const el = {}
             switch (true) {
-            case findTarget(event, '.delete-single-contact', el): {
+            case findTarget(event, ".delete-single-contact", el): {
                 //delete single user
                 const id = parseInt(el.target.dataset.id)
                 const type = el.target.dataset.type
@@ -194,9 +198,9 @@ export class ContactsOverview {
                 })
                 break
             }
-            case findTarget(event, '.respond-invite', el): {
+            case findTarget(event, ".respond-invite", el): {
                 const id = parseInt(el.target.dataset.id)
-                const invite = this.contacts.find(contact => contact.id === id && contact.type === 'to_userinvite')
+                const invite = this.contacts.find(contact => contact.id === id && contact.type === "to_userinvite")
                 const dialog = new RespondInviteDialog(
                     [invite],
                     contacts => this.contacts = this.contacts.concat(contacts),
@@ -219,7 +223,7 @@ export class ContactsOverview {
     // get IDs of selected contacts
     getSelected() {
         return Array.from(
-            this.dom.querySelectorAll('.entry-select:checked:not(:disabled)')
+            this.dom.querySelectorAll(".entry-select:checked:not(:disabled)")
         ).map(el => ({id: parseInt(el.dataset.id), type: el.dataset.type}))
     }
 
