@@ -9,25 +9,25 @@ export class DeleteUserDialog {
     init() {
         const buttons = [
             {
-                text: gettext('Delete'),
+                text: gettext("Delete"),
                 classes: "fw-dark",
                 click: () => {
-                    const usernamefieldValue = document.getElementById('username-confirmation').value
-                    const passwordfieldValue = document.getElementById('password').value
+                    const usernamefieldValue = document.getElementById("username-confirmation").value
+                    const passwordfieldValue = document.getElementById("password").value
                     if (usernamefieldValue === this.username && passwordfieldValue.length) {
                         this.deleteCurrentUser(passwordfieldValue)
                     }
                 }
             },
             {
-                type: 'cancel'
+                type: "cancel"
             }
         ]
         this.dialog = new Dialog({
-            id: 'confirmaccountdeletion',
-            title: gettext('Confirm deletion'),
+            id: "confirmaccountdeletion",
+            title: gettext("Confirm deletion"),
             body: deleteUserDialogTemplate(),
-            icon: 'exclamation-triangle',
+            icon: "exclamation-triangle",
             buttons,
             height: 250
         })
@@ -38,22 +38,22 @@ export class DeleteUserDialog {
         activateWait()
 
         postBare(
-            '/api/user/delete/',
+            "/api/user/delete/",
             {password}
         ).then(
             response => {
                 switch (response.status) {
-                case 204:
-                    window.location = '/'
+                case 200:
+                    window.location = "/"
                     break
                 case 403:
-                    addAlert('error', gettext('Staff accounts have to be deleted through the admin interface.'))
+                    addAlert("error", gettext("Staff accounts have to be deleted through the admin interface."))
                     break
                 case 401:
-                    addAlert('error', gettext('Password incorrect.'))
+                    addAlert("error", gettext("Password incorrect."))
                     break
                 default:
-                    addAlert('error', gettext('Could not delete user account.'))
+                    addAlert("error", gettext("Could not delete user account."))
                     break
                 }
                 deactivateWait()
