@@ -18,70 +18,71 @@ export class Profile {
             const smenu = new SiteMenu(this.app, "") // Nothing highlighted
             smenu.init()
             dropdownSelect(
-                this.dom.querySelector('#edit-avatar-pulldown'),
+                this.dom.querySelector("#edit-avatar-pulldown"),
                 {
                     onChange: value => {
                         switch (value) {
-                        case 'change':
+                        case "change":
                             changeAvatarDialog(this.app)
                             break
-                        case 'delete':
+                        case "delete":
                             deleteAvatarDialog(this.app)
                             break
                         }
                     },
-                    button: this.dom.querySelector('#edit-avatar-btn')
+                    button: this.dom.querySelector("#edit-avatar-btn")
                 }
             )
-            this.dom.addEventListener('click', event => {
+            this.dom.addEventListener("click", event => {
                 const el = {}
                 let dialog
                 switch (true) {
-                case findTarget(event, '#add-profile-email', el):
+                case findTarget(event, "#add-profile-email", el):
                     addEmailDialog(this.app)
                     break
-                case findTarget(event, '#fw-edit-profile-pwd', el):
+                case findTarget(event, "#fw-edit-profile-pwd", el):
                     changePwdDialog({username: this.user.username})
                     break
-                case findTarget(event, '#delete-account', el):
+                case findTarget(event, "#delete-account", el):
                     dialog = new DeleteUserDialog(
-                        this.dom.querySelector('#delete-account').dataset.username
+                        this.dom.querySelector("#delete-account").dataset.username
                     )
                     dialog.init()
                     break
-                case findTarget(event, '#submit-profile', el):
+                case findTarget(event, "#submit-profile", el):
                     this.save()
                     break
-                case findTarget(event, '.delete-email', el):
+                case findTarget(event, ".delete-email", el):
                     deleteEmailDialog(el.target, this.app)
                     break
-                case findTarget(event, '.delete-socialaccount', el):
+                case findTarget(event, ".delete-socialaccount", el):
                     deleteSocialaccountDialog(el.target, this.app)
                     break
                 default:
                     break
                 }
             })
-            this.dom.querySelectorAll('.primary-email-radio').forEach(el => el.addEventListener(
-                'change', () => changePrimaryEmailDialog(this.app)
+            this.dom.querySelectorAll(".primary-email-radio").forEach(el => el.addEventListener(
+                "change", () => changePrimaryEmailDialog(this.app)
             ))
         })
     }
 
     render() {
-        this.dom = document.createElement('body')
-        this.dom.classList.add('scrollable')
+        this.dom = document.createElement("body")
+        this.dom.classList.add("scrollable")
         this.dom.innerHTML = baseBodyTemplate({
             contents: profileContents(this.user, this.socialaccount_providers),
-            user: this.user
+            user: this.user,
+            app: this.app
         })
         document.body = this.dom
 
         ensureCSS([
-            'show_profile.css'
+            staticUrl("css/show_profile.css")
         ])
 
-        setDocTitle(gettext('Configure profile'), this.app)
+        setDocTitle(gettext("Configure profile"), this.app)
         const feedbackTab = new FeedbackTab()
         feedbackTab.init()
     }
@@ -90,18 +91,18 @@ export class Profile {
         activateWait()
 
         return post(
-            '/api/user/save/',
+            "/api/user/save/",
             {
                 form_data: JSON.stringify({
                     user: {
-                        username: this.dom.querySelector('#username').value,
-                        first_name: this.dom.querySelector('#first_name').value,
-                        last_name: this.dom.querySelector('#last_name').value
+                        username: this.dom.querySelector("#username").value,
+                        first_name: this.dom.querySelector("#first_name").value,
+                        last_name: this.dom.querySelector("#last_name").value
                     }
                 })
             }
         ).catch(
-            () => addAlert('error', gettext('Could not save profile data'))
+            () => addAlert("error", gettext("Could not save profile data"))
         ).then(
             () => {
                 deactivateWait()
