@@ -1,4 +1,4 @@
-import Cropper from 'cropperjs'
+import Cropper from "cropperjs"
 
 import {CopyrightDialog} from "../../copyright_dialog"
 
@@ -6,14 +6,14 @@ let mediaPreviewerImg = false
 
 export const imageEditModel = () => ({
     content: [{
-        title: gettext('Rotate Left'),
-        type: 'action',
-        tooltip: gettext('Rotate-left'),
+        title: gettext("Rotate Left"),
+        type: "action",
+        tooltip: gettext("Rotate-left"),
         order: 0,
         action: dialog => {
             const mediaPreviewerStyle = dialog.mediaPreviewer.currentStyle || window.getComputedStyle(dialog.mediaPreviewer, false)
-            rotateBase64Image(mediaPreviewerStyle.backgroundImage.slice(4, -1).replace(/"/g, ""), dialog.mediaInput.type, 'left').then(
-                response => dialog.mediaPreviewer.setAttribute('style', `background-image: url(${response});`)
+            rotateBase64Image(mediaPreviewerStyle.backgroundImage.slice(4, -1).replace(/"/g, ""), dialog.mediaInput.type, "left").then(
+                response => dialog.mediaPreviewer.setAttribute("style", `background-image: url(${response});`)
             )
             if (dialog.rotation === 0) {
                 dialog.rotation = 270
@@ -23,17 +23,17 @@ export const imageEditModel = () => ({
 
         },
         disabled: dialog => dialog.imageId,
-        icon: 'redo fa-rotate-180'
+        icon: "redo fa-rotate-180"
     },
     {
-        title: gettext('Rotate Right'),
-        type: 'action',
-        tooltip: gettext('Rotate-right'),
+        title: gettext("Rotate Right"),
+        type: "action",
+        tooltip: gettext("Rotate-right"),
         order: 1,
         action: dialog => {
             const mediaPreviewerStyle = dialog.mediaPreviewer.currentStyle || window.getComputedStyle(dialog.mediaPreviewer, false)
-            rotateBase64Image(mediaPreviewerStyle.backgroundImage.slice(4, -1).replace(/"/g, ""), dialog.mediaInput.type, 'right').then(
-                response => dialog.mediaPreviewer.setAttribute('style', `background-image: url(${response});`)
+            rotateBase64Image(mediaPreviewerStyle.backgroundImage.slice(4, -1).replace(/"/g, ""), dialog.mediaInput.type, "right").then(
+                response => dialog.mediaPreviewer.setAttribute("style", `background-image: url(${response});`)
             )
             if (dialog.rotation === 270) {
                 dialog.rotation = 0
@@ -42,17 +42,17 @@ export const imageEditModel = () => ({
             }
         },
         disabled: dialog => dialog.imageId,
-        icon: 'undo'
+        icon: "undo"
     },
     {
-        title: gettext('Crop'),
-        type: 'action',
-        tooltip: gettext('Crop image'),
+        title: gettext("Crop"),
+        type: "action",
+        tooltip: gettext("Crop image"),
         order: 2,
         action: dialog => {
             const mediaPreviewerStyle = dialog.mediaPreviewer.currentStyle || window.getComputedStyle(dialog.mediaPreviewer, false)
             //const base64data = mediaPreviewerStyle.backgroundImage.slice(4, -1).replace(/"/g, "")
-            mediaPreviewerImg = document.createElement('img')
+            mediaPreviewerImg = document.createElement("img")
             //img.src = `url(${base64data})`
             mediaPreviewerImg.src = mediaPreviewerStyle.backgroundImage.slice(4, -1).replace(/"/g, "")
             dialog.mediaPreviewer.parentElement.replaceChild(mediaPreviewerImg, dialog.mediaPreviewer)
@@ -63,12 +63,12 @@ export const imageEditModel = () => ({
             toggleCropMode(true, dialog, cropper)
         },
         disabled: dialog => dialog.imageId,
-        icon: 'crop'
+        icon: "crop"
     },
     {
-        title: gettext('Set Copyright'),
-        type: 'action',
-        tooltip: gettext('Specify copyright information'),
+        title: gettext("Set Copyright"),
+        type: "action",
+        tooltip: gettext("Specify copyright information"),
         order: 3,
         action: dialog => {
             const crDialog = new CopyrightDialog(dialog.copyright)
@@ -88,13 +88,13 @@ let oldButtons = false
 
 const toggleCropMode = (val, dialog, cropper) => {
     if (val && !oldButtons) {
-        dialog.mediaPreviewerDiv.classList.add('crop-mode')
+        dialog.mediaPreviewerDiv.classList.add("crop-mode")
         oldButtons = dialog.dialog.buttons
         dialog.dialog.setButtons([
             {
                 text: gettext("Crop"),
                 click: () => {
-                    dialog.mediaPreviewer.setAttribute('style', `background-image: url(${
+                    dialog.mediaPreviewer.setAttribute("style", `background-image: url(${
                         cropper.getCroppedCanvas().toDataURL(
                             dialog.mediaInput.type
                         )
@@ -106,7 +106,7 @@ const toggleCropMode = (val, dialog, cropper) => {
                 classes: "fw-dark"
             },
             {
-                type: 'cancel',
+                type: "cancel",
                 classes: "fw-orange",
                 click: () => {
                     cropper.destroy()
@@ -115,7 +115,7 @@ const toggleCropMode = (val, dialog, cropper) => {
             }
         ])
     } else {
-        dialog.mediaPreviewerDiv.classList.remove('crop-mode')
+        dialog.mediaPreviewerDiv.classList.remove("crop-mode")
         if (mediaPreviewerImg) {
             mediaPreviewerImg.parentElement.replaceChild(dialog.mediaPreviewer, mediaPreviewerImg)
             mediaPreviewerImg = false
@@ -138,7 +138,7 @@ const rotateBase64Image = (base64data, type, direction) => {
         image.onload = () => {
             canvas.height = image.width
             canvas.width = image.height
-            if (direction == 'left') {
+            if (direction == "left") {
                 ctx.rotate(90 * Math.PI / 180)
                 ctx.translate(0, -canvas.width)
             } else {
